@@ -1,7 +1,7 @@
 package App::CSelUtils;
 
-our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.080'; # VERSION
+our $DATE = '2019-07-27'; # DATE
+our $VERSION = '0.081'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,7 +70,7 @@ our %foosel_tree_action_args = (
         'x.name.is_plural' => 1,
         schema => ['array*', {
             of => ['str*', {
-                match => qr/\A(print_as_string|print_method:\w+(\.\w+)*|count)\z/,
+                match => qr/\A(dump(:\w+(\.\w+)*)?|print_as_string|print_method:\w+(\.\w+)*|count)\z/,
             }],
         }],
         default => ['print_as_string'],
@@ -99,6 +99,18 @@ our %foosel_tree_action_args = (
                     }
                 },
             },
+            dump => {
+                summary => 'Shortcut for --action dump',
+                is_flag => 1,
+                code => sub {
+                    my $args = shift;
+                    $args->{actions} //= [];
+                    my $actions = $args->{actions};
+                    unless (grep {$_ eq 'dump'} @$actions) {
+                        push @$actions, 'dump';
+                    }
+                },
+            },
             print_method => {
                 summary => '--print-method M is shortcut for --action print_method:M',
                 code => sub {
@@ -139,7 +151,19 @@ sub do_actions_on_nodes {
 
     my $res = [200, "OK"];
     for my $action (@$actions) {
-        if ($action eq 'count') {
+        if ($action =~ /\Adump:(.+)/) {
+            require Tree::ToTextLines;
+            my @attrs = split /\./, $1;
+            push @{ $res->[2] }, map {
+                Tree::ToTextLines::render_tree_as_text({
+                    show_guideline  => 1,
+                    on_show_node    => sub {
+                        my ($node, $level, $seniority, $is_last_child, $opts) = @_;
+                        "(".ref($node).") ".join(", ", map {"$_=" . ($node->$_ // 'undef')} @attrs);
+                    },
+                }, $_)
+              } @$nodes;
+        } elsif ($action eq 'count') {
             if (@$actions == 1) {
                 $res->[2] = ~~@$nodes;
             } else {
@@ -293,7 +317,7 @@ App::CSelUtils - Utilities related to Data::CSel
 
 =head1 VERSION
 
-This document describes version 0.080 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2019-07-26.
+This document describes version 0.081 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2019-07-27.
 
 =head1 DESCRIPTION
 
